All Classes and Interfaces
Class
Description
Config required to generate the additional static methods in Client interface.
An and expression will evaluate to either the left expression or the right expression.
Assigns an identifier to each rule then we use as a name for the generated method.
Assigns types to each expression and validates that the assigned types match the expected ones.
Java poet
ClassSpec to generate the response class for async paginated operations.Customization configuration for policy actions enums file.
Knowledge index to get access to the configured service auth schemes and operations overrides.
Represents a modeled auth scheme option.
Extension and utility methods for the
AuthSchemeCodegenMetadata class.Represents an authentication option, encapsulating attributes such as the authentication type
and whether the payload should be unsigned.
Contains maps from all sigv4 based
AuthType to SigV4SignerDefaults that we can then transform for use in
codegen.Generator tasks for AWS style clients.
Provides the Poet specs for AWS Service models.
Base class containing common logic shared between the sync waiter class and the async waiter class
Base class contains shared logic used in both sync waiter and async waiter interfaces.
Synthetic expression used to group and codegen boolean (non-assignment) conditions from a rule set.
Represents a
not function call as an expression.A bracket specifier within an
IndexExpression.A
BracketSpecifier with some kind of content.A
BracketSpecifier without content, i.e.A
BracketSpecifier with a question-mark expression, as in [?Foo].Container for service models and config files.
Deprecated.
Represents a Poet generated class
Enum that identifies the generated client type.
Builder for a
CodeGenerator.Encapsulates the codegen serialization logic for the given value.
Codegen for List values.
Codegen for literal values.
Codegen for Map values.
Codegen for String values.
Resolves
CodegenSerializer for a given instance.Formats the generated code and write it to the underlying file.
Task for classes shared by
AsyncClientGeneratorTasks and SyncClientGeneratorTasks.A comparator within a
ComparatorExpression.A comparator expression is two expressions separated by a
Comparator.A
Parser that invokes a list of converters, returning the first converter that was successful.Computes all the symbols, locals and params, used by each of the rules, either directly or transitively.
Customization to allow generation of additional setter overloads for a 'convenience' type (i.e.
The current-node expression '@': https://jmespath.org/specification.html#current-node
service-2.json models can be manually modified via defining properties in an associated customization.config
file.Validator that ensures CustomizationConfig settings are not conflicting.
Customization to change package name.
Default implementation of naming strategy respecting.
Default implementation of
ProtocolMetadataConstants.Configuration for generation in a
OperationDocProvider.Builder for a Javadoc string that orders sections consistently.
Generates an auth scheme provider that resolves authentication schemes from endpoint rules.
Represents an endpoint expression.
Knowledge index to get access to endpoint parameters known to the client builder classes.
This trait can be used to resolve the endpoint of an API using the original endpoint
derived from client or set by customer.
Represents a single enum field in a enum.
Represents an error expression.
Expresses content of the error trait
MarshallerSpec for event shapes in Json protocol
Generates implementation class for the event stream response handler builder.
Spec for generated response handler builder
Generates response handler interface for operations with an event stream response.
Processor for eventstreams with shared events.
Utils for event streaming code generation.
Generates the implementation for the builder of an event stream visitor.
Spec for builder interface for visitor.
Class for loading and caching code example metadata from JSON files.
Operations with explicit String payloads are not supported for services with Query protocol.
An expression is any statement that can be executed in isolation from other parts of a JMESPath string.
Utility methods for parsing endpoint rules expressions.
An expression type is an expression prefixed by "&".
An argument to a
FunctionExpression.Represents a function call expression.
A function allowing users to easily transform and filter data in JMESPath expressions.
Common paths used by generator tasks.
Base class for tasks.
Parameters for generator tasks.
Represents a list of headers expression.
Class to process the hostPrefix value in the
EndpointTrait class.Class to map the HttpChecksum trait of an operation.
The logic for handling the "httpChecksumRequired" trait within the code generator.
The logic for handling the Flexible "httpChecksum" trait within the code generator.
Represents an index access expression.
An index expression is used to access elements in a list.
Builds an intermediate model to be used by the templates from the service model and
customizations.
Interface used by the
IntermediateModelBuilder to process the service model to add and
modify ShapeModels to the IntermediateModel.Formats the generated java source code.
A code interpreter for converting JMESPath expressions into Java expressions.
Parses a JMESPath expression string into an
Expression.A visitor across all of the JMESPath expression types.
MarshallerSpec for Json protocol
A key-value expression within a
MultiSelectHash.Synthetic expression used to group and codegen assignment "conditions" from a rule set.
Removes HTML "anchor" tags from a string.
Represents a list of expressions.
A literal JSON value embedded in a JMESPath expression.
Represents a literal boolean value.
Represents a literal integer value.
Represents a literal string value.
Represents a generic parameter that can be code generated, but isn't tied to a model shape
Marks specific service operations as having the long polling trait.
Helper methods for working with the long poll trait for operations.
A processor that validates shape names in service models to ensure they start with uppercase letters.
Represents a member access expression.
Contains custom properties to override in service and intermediate model metadata.
This processor handles preprocess modifications to service metadata and
postprocess modifications to intermediate model metadata.
Synthetic expression to represent direct method calls for codegen.
Knowledge index of the configured auth schemes concrete classes.
Knowledge index to get access to the configured service auth schemes and operations overrides.
Generates an auth scheme provider implementation based on the service model's authentication configuration.
Exception thrown during code generation to signal that the model is invalid.
Creates the method specs for common method overrides for service models.
Context object for
ModelValidators.A multi-select-hash expression is similar to a multi-select-list
MultiSelectList expression, except that a hash is
created instead of a list.A multiselect expression is used to extract a subset of elements from a JSON hash.
Strategy to name various Java constructs based on the naming in the model and potentially customizations.
Services that have "legacy" streams, Kinesis and Transcribe Streaming builds should fail if there is a new
evenstream added, that codegen doesn't know about.
Trait which defines if a given request needs to be authenticated.
A not-expression negates the result of an expression.
Provides documentation for an operation method on the client interface.
Use operationModifiers customization to exclude a given operation, or add a
wrapper around the result shape.
An or expression will evaluate to either the left expression or the right expression.
Emits the package-info.java for the base service package.
Represents the structure for each operation in paginators-1.json file
This class is used to generate auto-paginated APIs.
POJO class to represent the paginators.json file.
A paren-expression allows a user to override the precedence order of an expression, e.g.
A JMESPath parser, for generating a
ParseResult from a string between two provided bounds.The result of a
Parser.parse(int, int) call.A pipe expression combines two expressions, separated by the | character.
A set of
Collector implementations, similar to Collectors, but for poet types.Extension and convenience methods to Poet that use the intermediate model.
Represents a custom request transformer for API requests.
Visitor that rewrites expressions in preparation for codegen.
Represents a properties expression, part of an endpoint expression.
Keeps the set of
OperationMetadataAttribute constants attributes per operation/protocol.Enum that maps protocol to metadata attribute constants for a given operation.
Resolves the protocol from the service model
protocol and protocols fields.This processor removes the member *message* in the exception shapes from the
intermediate model.
Visitor that renames locals assignments to use idiomatic java names.
Class to map the requestcompression trait of an operation.
The logic for handling the "requestCompression" trait within the code generator.
Generate ResponseMetadata class
Base class for all the rewriting expression tasks.
Represents an expression within an endpoint rules set, either explicit or synthetically created for codegen.
Visitor for all the expressions defined in the endpoints rule sets.
Represents a function from the endpoint rules set standard library.
A version of
RulesEngineRuntimeGeneratorTask that copies a minimal
set of the interpreter related classes.Represents a rule set expression.
Indicating a field that can be an ARN
With Endpoints 2.0, the endpoint rule set is responsible for adding the prefix, so we remove it from the model to avoid
errors in constructing the endpoint.
With Endpoints 2.0, the endpoint rule set for S3 is responsible for taking the
Bucket parameter from the input and
adding it to the request URI.Customized response class spec for async paginated operations that indicate the
last page by returning the same token passed in the request object.
Customized response class spec for sync paginated operations that indicate the
last page by returning the same token passed in the request object.
Use shapeModifiers customization to add/remove shape members or to modify the
properties of a member.
Use shapeSubstitutions customization to override all appearances of the given
shape with a new shape, and optionally use a specific member of the original
shape as the data source.
This validates that services with the
CustomizationConfig.shareModelConfig attribute specified are being generated
after the service they are attempting to share models with.Validator that ensures any shapes shared between two services are completely identical.
Contains custom properties for services that share models with other services.
Knowledge index to compute the sets of operations that share the same set of sigv4 overrides.
Tracks a set of explicitly enabled signer properties for the family of AWS SigV4 signers.
Simple generator task that writes a string to a file.
Enum describing all the convenience overloads we generate for operation methods.
A slice expression allows you to select a contiguous subset of an array.
This processor only runs for services using the
smithy-rpc-v2-cbor protocol.A Poet static import definition to enable inclusion of static imports at code generation time
A subexpression is a combination of two expressions separated by the ‘.’ char.
The right side of a
SubExpression.Java poet
ClassSpec to generate the response class for sync paginated operations.Tokenizer for string literals inside a rule set document.
Helper class for resolving Poet
TypeNames for use in model classes.Used to determine the Java types for the service model.
Valid values for the
CustomizationConfig.setUnderscoresInNameBehavior(software.amazon.awssdk.codegen.model.config.customization.UnderscoresInNameBehavior) customization.This process enforces constraints placed on the "useLegacyEventGenerationSchemeProcessor"; i.e.
Config required to generate the utilities method that returns an instance of
hand-written Utilities class
A wildcard expression is a expression of either * or [*].
MarshallerSpec for Xml protocol
ClassLoaderHelper