Package software.amazon.awssdk.codegen
Class AddEmptyOutputShape
java.lang.Object
software.amazon.awssdk.codegen.AddEmptyOutputShape
- All Implemented Interfaces:
IntermediateModelShapeProcessor
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprocess(Map<String, OperationModel> currentOperations, Map<String, ShapeModel> currentShapes)
-
Constructor Details
-
AddEmptyOutputShape
-
-
Method Details
-
process
public Map<String,ShapeModel> process(Map<String, OperationModel> currentOperations, Map<String, ShapeModel> currentShapes) - Specified by:
processin interfaceIntermediateModelShapeProcessor- Parameters:
currentOperations- Current operations that have been added to the intermediate model.currentShapes- Current shapes that have been added to the intermediate model- Returns:
- Map of shape name to ShapeModel to add to the intermediate model.
-