Uses of Class
software.amazon.awssdk.codegen.docs.DocumentationBuilder
Packages that use DocumentationBuilder
-
Uses of DocumentationBuilder in software.amazon.awssdk.codegen.docs
Methods in software.amazon.awssdk.codegen.docs that return DocumentationBuilderModifier and TypeMethodDescriptionDocumentationBuilder.asyncThrows(String exceptionClass, String exceptionDoc) Async exceptions are not thrown from the method, rather the returnedCompletableFutureis completed exceptionally (CompletableFuture.completeExceptionally(Throwable).DocumentationBuilder.asyncThrows(List<Pair<String, String>> exceptions) Adds multiple async throws to the Javadoc for each exception name / exception doc pair.DocumentationBuilder.asyncThrows(Pair<String, String>... exceptions) Adds multiple async throws to the Javadoc for each exception name / exception doc pair.DocumentationBuilder.description(String docs) Description of javaodc comment.Adds a new param to the Javadoc.Adds a new param to the Javadoc.Adds documentation for return value.Adds documentation for return value.Adds a @see reference to the Javadocs.Adds a @see reference to the Javadocs.DocumentationBuilder.syncThrows(String exceptionClass, String exceptionDoc) Adds a throws tag to the Javadoc.DocumentationBuilder.syncThrows(List<Pair<String, String>> exceptions) Adds multiple throws tag to the Javadoc for each exception name / exception doc pair.DocumentationBuilder.syncThrows(Pair<String, String>... exceptions) Adds multiple throws tag to the Javadoc for each exception name / exception doc pair.Adds an arbitrary tag with values to the Javadoc.