Class BaseExceptionClassGeneratorTasks
java.lang.Object
java.util.concurrent.ForkJoinTask<Void>
java.util.concurrent.RecursiveAction
software.amazon.awssdk.codegen.emitters.GeneratorTask
software.amazon.awssdk.codegen.emitters.tasks.BaseGeneratorTasks
software.amazon.awssdk.codegen.emitters.tasks.BaseExceptionClassGeneratorTasks
- All Implemented Interfaces:
Serializable,Future<Void>
- See Also:
-
Field Summary
Fields inherited from class software.amazon.awssdk.codegen.emitters.tasks.BaseGeneratorTasks
baseDirectory, log, model, testDirectory -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected List<GeneratorTask>protected booleanhasTasks()If a custom base class is provided we assume it already exists and does not need to be generatedMethods inherited from class software.amazon.awssdk.codegen.emitters.tasks.BaseGeneratorTasks
compute, createPoetGeneratorTask, createPoetGeneratorTestTask, infoMethods inherited from class java.util.concurrent.RecursiveAction
exec, getRawResult, setRawResultMethods inherited from class java.util.concurrent.ForkJoinTask
adapt, adapt, adapt, cancel, compareAndSetForkJoinTaskTag, complete, completeExceptionally, fork, get, get, getException, getForkJoinTaskTag, getPool, getQueuedTaskCount, getSurplusQueuedTaskCount, helpQuiesce, inForkJoinPool, invoke, invokeAll, invokeAll, invokeAll, isCancelled, isCompletedAbnormally, isCompletedNormally, isDone, join, peekNextLocalTask, pollNextLocalTask, pollTask, quietlyComplete, quietlyInvoke, quietlyJoin, reinitialize, setForkJoinTaskTag, tryUnfork
-
Constructor Details
-
BaseExceptionClassGeneratorTasks
-
-
Method Details
-
hasTasks
protected boolean hasTasks()If a custom base class is provided we assume it already exists and does not need to be generated- Overrides:
hasTasksin classBaseGeneratorTasks
-
createTasks
- Specified by:
createTasksin classBaseGeneratorTasks- Throws:
Exception
-