Class RulesEngineRuntimeLiteGeneratorTask
- java.lang.Object
-
- java.util.concurrent.ForkJoinTask<Void>
-
- java.util.concurrent.RecursiveAction
-
- software.amazon.awssdk.codegen.emitters.GeneratorTask
-
- software.amazon.awssdk.codegen.emitters.tasks.BaseGeneratorTasks
-
- software.amazon.awssdk.codegen.emitters.tasks.RulesEngineRuntimeGeneratorTask
-
- software.amazon.awssdk.codegen.emitters.tasks.RulesEngineRuntimeLiteGeneratorTask
-
- All Implemented Interfaces:
Serializable,Future<Void>
public final class RulesEngineRuntimeLiteGeneratorTask extends RulesEngineRuntimeGeneratorTask
A version ofRulesEngineRuntimeGeneratorTaskthat copies a minimal set of the interpreter related classes. This set represents the only classes that need to be copied when compiled rules are enabled.
-
-
Field Summary
-
Fields inherited from class software.amazon.awssdk.codegen.emitters.tasks.RulesEngineRuntimeGeneratorTask
RUNTIME_CLASS_NAME
-
Fields inherited from class software.amazon.awssdk.codegen.emitters.tasks.BaseGeneratorTasks
baseDirectory, log, model, testDirectory
-
-
Constructor Summary
Constructors Constructor Description RulesEngineRuntimeLiteGeneratorTask(GeneratorTaskParams generatorTaskParams)
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description protected List<String>rulesEngineJavaFilePaths(Collection<String> runtimeEngineFiles)-
Methods inherited from class software.amazon.awssdk.codegen.emitters.tasks.RulesEngineRuntimeGeneratorTask
createTasks
-
Methods inherited from class software.amazon.awssdk.codegen.emitters.tasks.BaseGeneratorTasks
compute, createPoetGeneratorTask, createPoetGeneratorTestTask, hasTasks, info
-
Methods inherited from class java.util.concurrent.RecursiveAction
exec, getRawResult, setRawResult
-
Methods inherited from class java.util.concurrent.ForkJoinTask
adapt, adapt, adapt, cancel, compareAndSetForkJoinTaskTag, complete, completeExceptionally, fork, get, get, getException, getForkJoinTaskTag, getPool, getQueuedTaskCount, getSurplusQueuedTaskCount, helpQuiesce, inForkJoinPool, invoke, invokeAll, invokeAll, invokeAll, isCancelled, isCompletedAbnormally, isCompletedNormally, isDone, join, peekNextLocalTask, pollNextLocalTask, pollTask, quietlyComplete, quietlyInvoke, quietlyJoin, reinitialize, setForkJoinTaskTag, tryUnfork
-
-
-
-
Constructor Detail
-
RulesEngineRuntimeLiteGeneratorTask
public RulesEngineRuntimeLiteGeneratorTask(GeneratorTaskParams generatorTaskParams)
-
-
Method Detail
-
rulesEngineJavaFilePaths
protected List<String> rulesEngineJavaFilePaths(Collection<String> runtimeEngineFiles)
- Overrides:
rulesEngineJavaFilePathsin classRulesEngineRuntimeGeneratorTask
-
-