Package software.amazon.awssdk.codegen.internal
-
Interface Summary Interface Description ProtocolMetadataConstants Keeps the set ofOperationMetadataAttributeconstants attributes per operation/protocol. -
Class Summary Class Description ClassLoaderHelper Deprecated. should be replaced withClassLoaderHelperConstant DefaultProtocolMetadataConstants Default implementation ofProtocolMetadataConstants.DocumentationUtils ExampleMetadataProvider Class for loading and caching code example metadata from JSON files.ExampleMetadataProvider.ExampleData Jackson TypeUtils Used to determine the Java types for the service model.TypeUtils.TypeKey Utils -
Enum Summary Enum Description ProtocolMetadataDefault Enum that maps protocol to metadata attribute constants for a given operation.