Uses of Class
software.amazon.awssdk.codegen.model.intermediate.Metadata
-
Packages that use Metadata Package Description software.amazon.awssdk.codegen.internal software.amazon.awssdk.codegen.model.intermediate -
-
Uses of Metadata in software.amazon.awssdk.codegen.internal
Methods in software.amazon.awssdk.codegen.internal with parameters of type Metadata Modifier and Type Method Description Optional<String>ExampleMetadataProvider. createLinkToCodeExample(Metadata metadata, String operationName)Creates a link to a code example for the given operation.static StringDocumentationUtils. createLinkToServiceDocumentation(Metadata metadata, String name)Create the HTML for a link to the operation/shape core AWS docs sitestatic StringDocumentationUtils. createLinkToServiceDocumentation(Metadata metadata, ShapeModel shapeModel)Create the HTML for a link to the operation/shape core AWS docs siteList<ExampleMetadataProvider.ExampleData>ExampleMetadataProvider. getServiceCodeExamples(Metadata metadata)Gets all code examples for a specific service. -
Uses of Metadata in software.amazon.awssdk.codegen.model.intermediate
Methods in software.amazon.awssdk.codegen.model.intermediate with parameters of type Metadata Modifier and Type Method Description voidIntermediateModel. setMetadata(Metadata metadata)Constructors in software.amazon.awssdk.codegen.model.intermediate with parameters of type Metadata Constructor Description IntermediateModel(Metadata metadata, Map<String,OperationModel> operations, Map<String,ShapeModel> shapes, CustomizationConfig customizationConfig)IntermediateModel(Metadata metadata, Map<String,OperationModel> operations, Map<String,ShapeModel> shapes, CustomizationConfig customizationConfig, OperationModel endpointOperation, Map<String,PaginatorDefinition> paginators, NamingStrategy namingStrategy, Map<String,WaiterDefinition> waiters, EndpointRuleSetModel endpointRuleSetModel, EndpointTestSuiteModel endpointTestSuiteModel, Map<String,ClientContextParam> clientContextParams)
-