Package software.amazon.awssdk.codegen
package software.amazon.awssdk.codegen
-
ClassDescriptionContainer for service models and config files.Builder for a
CodeGenerator.Builds an intermediate model to be used by the templates from the service model and customizations.Interface used by theIntermediateModelBuilderto process the service model to add and modify ShapeModels to theIntermediateModel.