Class AsyncClientClass

java.lang.Object
software.amazon.awssdk.codegen.poet.client.AsyncClientInterface
software.amazon.awssdk.codegen.poet.client.AsyncClientClass
All Implemented Interfaces:
ClassSpec

public final class AsyncClientClass extends AsyncClientInterface
  • Constructor Details

  • Method Details

    • createTypeSpec

      protected com.squareup.javapoet.TypeSpec.Builder createTypeSpec()
      Overrides:
      createTypeSpec in class AsyncClientInterface
    • addInterfaceClass

      protected void addInterfaceClass(com.squareup.javapoet.TypeSpec.Builder type)
      Overrides:
      addInterfaceClass in class AsyncClientInterface
    • addAnnotations

      protected void addAnnotations(com.squareup.javapoet.TypeSpec.Builder type)
      Overrides:
      addAnnotations in class AsyncClientInterface
    • addModifiers

      protected void addModifiers(com.squareup.javapoet.TypeSpec.Builder type)
      Overrides:
      addModifiers in class AsyncClientInterface
    • addFields

      protected void addFields(com.squareup.javapoet.TypeSpec.Builder type)
      Overrides:
      addFields in class AsyncClientInterface
    • addAdditionalMethods

      protected void addAdditionalMethods(com.squareup.javapoet.TypeSpec.Builder type)
      Overrides:
      addAdditionalMethods in class AsyncClientInterface
    • addWaiterMethod

      protected void addWaiterMethod(com.squareup.javapoet.TypeSpec.Builder type)
      Overrides:
      addWaiterMethod in class AsyncClientInterface
    • operations

      protected List<com.squareup.javapoet.MethodSpec> operations()
      Overrides:
      operations in class AsyncClientInterface
      Returns:
      List generated of methods for all operations.
    • serviceClientConfigMethod

      protected com.squareup.javapoet.MethodSpec serviceClientConfigMethod()
      Overrides:
      serviceClientConfigMethod in class AsyncClientInterface
    • addCloseMethod

      protected void addCloseMethod(com.squareup.javapoet.TypeSpec.Builder type)
      Overrides:
      addCloseMethod in class AsyncClientInterface
    • operationBody

      protected com.squareup.javapoet.MethodSpec.Builder operationBody(com.squareup.javapoet.MethodSpec.Builder builder, OperationModel opModel)
      Description copied from class: AsyncClientInterface
      Add the implementation body. The interface implements all methods by throwing an UnsupportedOperationException except for simple method overloads which just delegate to the traditional request/response method. This is overridden in AsyncClientClass to add an actual implementation.
      Overrides:
      operationBody in class AsyncClientInterface
      Parameters:
      builder - Current MethodSpec.Builder to add implementation to.
      opModel - Operation to generate method body for.
      Returns:
      Builder with method body added.
    • className

      public com.squareup.javapoet.ClassName className()
      Specified by:
      className in interface ClassSpec
      Overrides:
      className in class AsyncClientInterface
      Returns:
      The Poet representation of the class being generated, this may be used by other classes
    • staticImports

      public Iterable<StaticImport> staticImports()
      Description copied from interface: ClassSpec
      An optional hook to allow inclusion of static imports for example converting:
      
       import software.amazon.awssdk.utils.StringUtils;
       //...
         if(StringUtils.isBlank(value))...
       
      to
      
       import software.amazon.awssdk.utils.StringUtils.isBlank;
       //...
         if(isBlank(value))...
       
      Returns:
      the static imports to include
    • utilitiesMethod

      protected com.squareup.javapoet.MethodSpec utilitiesMethod()
      Overrides:
      utilitiesMethod in class AsyncClientInterface
    • addBatchManagerMethod

      protected void addBatchManagerMethod(com.squareup.javapoet.TypeSpec.Builder type)
      Overrides:
      addBatchManagerMethod in class AsyncClientInterface