Class AsyncClientInterface

java.lang.Object
software.amazon.awssdk.codegen.poet.client.AsyncClientInterface
All Implemented Interfaces:
ClassSpec
Direct Known Subclasses:
AsyncClientClass, DelegatingAsyncClientClass

public class AsyncClientInterface extends Object implements ClassSpec
  • Field Details

    • STREAMING_TYPE_VARIABLE

      public static final com.squareup.javapoet.TypeVariableName STREAMING_TYPE_VARIABLE
    • model

      protected final IntermediateModel model
    • className

      protected final com.squareup.javapoet.ClassName className
    • clientPackageName

      protected final String clientPackageName
  • Constructor Details

  • Method Details

    • poetSpec

      public com.squareup.javapoet.TypeSpec poetSpec()
      Specified by:
      poetSpec in interface ClassSpec
      Returns:
      The actual class specification generated from a PoetSpec.builder()... implementation
    • createTypeSpec

      protected com.squareup.javapoet.TypeSpec.Builder createTypeSpec()
    • addInterfaceClass

      protected void addInterfaceClass(com.squareup.javapoet.TypeSpec.Builder type)
    • addAnnotations

      protected void addAnnotations(com.squareup.javapoet.TypeSpec.Builder type)
    • addModifiers

      protected void addModifiers(com.squareup.javapoet.TypeSpec.Builder type)
    • addCloseMethod

      protected void addCloseMethod(com.squareup.javapoet.TypeSpec.Builder type)
    • addFields

      protected void addFields(com.squareup.javapoet.TypeSpec.Builder type)
    • addAdditionalMethods

      protected void addAdditionalMethods(com.squareup.javapoet.TypeSpec.Builder type)
    • addWaiterMethod

      protected void addWaiterMethod(com.squareup.javapoet.TypeSpec.Builder type)
    • addBatchManagerMethod

      protected void addBatchManagerMethod(com.squareup.javapoet.TypeSpec.Builder type)
    • className

      public com.squareup.javapoet.ClassName className()
      Specified by:
      className in interface ClassSpec
      Returns:
      The Poet representation of the class being generated, this may be used by other classes
    • operations

      protected Iterable<com.squareup.javapoet.MethodSpec> operations()
      Returns:
      List generated of methods for all operations.
    • paginatedTraditionalMethod

      protected com.squareup.javapoet.MethodSpec paginatedTraditionalMethod(OperationModel opModel)
    • paginatedMethodBody

      protected com.squareup.javapoet.MethodSpec.Builder paginatedMethodBody(com.squareup.javapoet.MethodSpec.Builder builder, OperationModel operationModel)
    • operationBody

      protected com.squareup.javapoet.MethodSpec.Builder operationBody(com.squareup.javapoet.MethodSpec.Builder builder, OperationModel operationModel)
      Add the implementation body. The interface implements all methods by throwing an UnsupportedOperationException except for simple method overloads which just delegate to the traditional request/response method. This is overridden in AsyncClientClass to add an actual implementation.
      Parameters:
      builder - Current MethodSpec.Builder to add implementation to.
      operationModel - Operation to generate method body for.
      Returns:
      Builder with method body added.
    • traditionalMethod

      protected com.squareup.javapoet.MethodSpec traditionalMethod(OperationModel opModel)
    • utilitiesMethod

      protected com.squareup.javapoet.MethodSpec utilitiesMethod()
    • serviceClientConfigMethod

      protected com.squareup.javapoet.MethodSpec serviceClientConfigMethod()
    • utilitiesOperationBody

      protected com.squareup.javapoet.MethodSpec.Builder utilitiesOperationBody(com.squareup.javapoet.MethodSpec.Builder builder)
    • waiterOperationBody

      protected com.squareup.javapoet.MethodSpec.Builder waiterOperationBody(com.squareup.javapoet.MethodSpec.Builder builder)
    • batchManagerOperationBody

      protected com.squareup.javapoet.MethodSpec.Builder batchManagerOperationBody(com.squareup.javapoet.MethodSpec.Builder builder)