Class CustomizationConfigValidator

  • All Implemented Interfaces:
    ModelValidator

    public final class CustomizationConfigValidator
    extends Object
    implements ModelValidator
    Validator that ensures CustomizationConfig settings are not conflicting. This validator returns a validation entry if mutually exclusive customization options are set simultaneously, such as both the global underscoresInNameBehavior and the granular allowedUnderscoreNames list.