Package software.amazon.awssdk.codegen.validation
-
Interface Summary Interface Description ModelValidator -
Class Summary Class Description CustomizationConfigValidator Validator that ensures CustomizationConfig settings are not conflicting.ModelInvalidException.Builder ModelValidationContext Context object forModelValidators.ModelValidationContext.Builder ModelValidationReport SharedModelsValidator Validator that ensures any shapes shared between two services are completely identical.ValidationEntry -
Enum Summary Enum Description ValidationErrorId ValidationErrorSeverity -
Exception Summary Exception Description ModelInvalidException Exception thrown during code generation to signal that the model is invalid.