Package software.amazon.awssdk.codegen
Interface IntermediateModelShapeProcessor
- All Known Implementing Classes:
AddEmptyOutputShape
public interface IntermediateModelShapeProcessor
Interface used by the
IntermediateModelBuilder to process the service model to add and
modify ShapeModels to the IntermediateModel.-
Method Summary
Modifier and TypeMethodDescriptionprocess(Map<String, OperationModel> currentOperations, Map<String, ShapeModel> currentShapes)
-
Method Details
-
process
Map<String,ShapeModel> process(Map<String, OperationModel> currentOperations, Map<String, ShapeModel> currentShapes) - Parameters:
currentOperations- Current operations that have been added to the intermediate model.currentShapes- Current shapes that have been added to the intermediate model- Returns:
- Map of shape name to ShapeModel to add to the intermediate model.
-