Class AndExpression
java.lang.Object
software.amazon.awssdk.codegen.jmespath.component.AndExpression
An and expression will evaluate to either the left expression or the right expression. If the expression on the left hand side
is a truth-like value, then the value on the right hand side is returned. Otherwise the result of the expression on the left
hand side is returned.
Examples:
- True && False
- Number && EmptyList
- a == `1` && b == `2`
-
Constructor Summary
Constructors -
Method Summary
-
Constructor Details
-
AndExpression
-
-
Method Details
-
leftExpression
-
rightExpression
-