Class AsyncClientClass
java.lang.Object
software.amazon.awssdk.codegen.poet.client.AsyncClientInterface
software.amazon.awssdk.codegen.poet.client.AsyncClientClass
- All Implemented Interfaces:
ClassSpec
-
Field Summary
Fields inherited from class software.amazon.awssdk.codegen.poet.client.AsyncClientInterface
clientPackageName, STREAMING_TYPE_VARIABLE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected voidaddAdditionalMethods(com.squareup.javapoet.TypeSpec.Builder type) protected voidaddAnnotations(com.squareup.javapoet.TypeSpec.Builder type) protected voidaddBatchManagerMethod(com.squareup.javapoet.TypeSpec.Builder type) protected voidaddCloseMethod(com.squareup.javapoet.TypeSpec.Builder type) protected voidaddFields(com.squareup.javapoet.TypeSpec.Builder type) protected voidaddInterfaceClass(com.squareup.javapoet.TypeSpec.Builder type) protected voidaddModifiers(com.squareup.javapoet.TypeSpec.Builder type) protected voidaddWaiterMethod(com.squareup.javapoet.TypeSpec.Builder type) com.squareup.javapoet.ClassNameprotected com.squareup.javapoet.TypeSpec.Builderprotected com.squareup.javapoet.MethodSpec.BuilderoperationBody(com.squareup.javapoet.MethodSpec.Builder builder, OperationModel opModel) Add the implementation body.protected List<com.squareup.javapoet.MethodSpec>protected com.squareup.javapoet.MethodSpecAn optional hook to allow inclusion of static imports for example converting:protected com.squareup.javapoet.MethodSpecMethods inherited from class software.amazon.awssdk.codegen.poet.client.AsyncClientInterface
batchManagerOperationBody, paginatedMethodBody, paginatedTraditionalMethod, poetSpec, traditionalMethod, utilitiesOperationBody, waiterOperationBody
-
Constructor Details
-
AsyncClientClass
-
-
Method Details
-
createTypeSpec
protected com.squareup.javapoet.TypeSpec.Builder createTypeSpec()- Overrides:
createTypeSpecin classAsyncClientInterface
-
addInterfaceClass
protected void addInterfaceClass(com.squareup.javapoet.TypeSpec.Builder type) - Overrides:
addInterfaceClassin classAsyncClientInterface
-
addAnnotations
protected void addAnnotations(com.squareup.javapoet.TypeSpec.Builder type) - Overrides:
addAnnotationsin classAsyncClientInterface
-
addModifiers
protected void addModifiers(com.squareup.javapoet.TypeSpec.Builder type) - Overrides:
addModifiersin classAsyncClientInterface
-
addFields
protected void addFields(com.squareup.javapoet.TypeSpec.Builder type) - Overrides:
addFieldsin classAsyncClientInterface
-
addAdditionalMethods
protected void addAdditionalMethods(com.squareup.javapoet.TypeSpec.Builder type) - Overrides:
addAdditionalMethodsin classAsyncClientInterface
-
addWaiterMethod
protected void addWaiterMethod(com.squareup.javapoet.TypeSpec.Builder type) - Overrides:
addWaiterMethodin classAsyncClientInterface
-
operations
- Overrides:
operationsin classAsyncClientInterface- Returns:
- List generated of methods for all operations.
-
serviceClientConfigMethod
protected com.squareup.javapoet.MethodSpec serviceClientConfigMethod()- Overrides:
serviceClientConfigMethodin classAsyncClientInterface
-
addCloseMethod
protected void addCloseMethod(com.squareup.javapoet.TypeSpec.Builder type) - Overrides:
addCloseMethodin classAsyncClientInterface
-
operationBody
protected com.squareup.javapoet.MethodSpec.Builder operationBody(com.squareup.javapoet.MethodSpec.Builder builder, OperationModel opModel) Description copied from class:AsyncClientInterfaceAdd the implementation body. The interface implements all methods by throwing anUnsupportedOperationExceptionexcept for simple method overloads which just delegate to the traditional request/response method. This is overridden inAsyncClientClassto add an actual implementation.- Overrides:
operationBodyin classAsyncClientInterface- Parameters:
builder- CurrentMethodSpec.Builderto add implementation to.opModel- Operation to generate method body for.- Returns:
- Builder with method body added.
-
className
public com.squareup.javapoet.ClassName className()- Specified by:
classNamein interfaceClassSpec- Overrides:
classNamein classAsyncClientInterface- Returns:
- The Poet representation of the class being generated, this may be used by other classes
-
staticImports
Description copied from interface:ClassSpecAn optional hook to allow inclusion of static imports for example converting:
toimport software.amazon.awssdk.utils.StringUtils; //... if(StringUtils.isBlank(value))...import software.amazon.awssdk.utils.StringUtils.isBlank; //... if(isBlank(value))...- Returns:
- the static imports to include
-
utilitiesMethod
protected com.squareup.javapoet.MethodSpec utilitiesMethod()- Overrides:
utilitiesMethodin classAsyncClientInterface
-
addBatchManagerMethod
protected void addBatchManagerMethod(com.squareup.javapoet.TypeSpec.Builder type) - Overrides:
addBatchManagerMethodin classAsyncClientInterface
-