Class PaginatorDefinitionValidator
java.lang.Object
software.amazon.awssdk.codegen.validation.PaginatorDefinitionValidator
- All Implemented Interfaces:
ModelValidator
Validates paginator definitions against the service model. Checks that:
- Each paginator references an operation that exists in the model
- Input tokens reference valid members in the request shape
- Output tokens reference valid members in the response shape
- Result keys reference valid members in the response shape
- The more_results field, if specified, references a valid member in the response shape
- The limit_key field, if specified, references a valid member in the request shape
-
Constructor Summary
Constructors -
Method Summary
-
Constructor Details
-
PaginatorDefinitionValidator
public PaginatorDefinitionValidator()
-
-
Method Details
-
validateModels
- Specified by:
validateModelsin interfaceModelValidator
-